pub struct Dsl;Implementations
Sourceimpl Dsl
impl Dsl
Sourcepub fn compile(
tree: &Tree,
store_ids: &[&str],
) -> Result<(List<u64>, VariableList<u16>, VariableList<u16>, VariableList<u16>, VariableList<u8>, VariableList<u16>, VariableList<u16>, VariableList<u16>, VariableList<u16>), DslError>
pub fn compile( tree: &Tree, store_ids: &[&str], ) -> Result<(List<u64>, VariableList<u16>, VariableList<u16>, VariableList<u16>, VariableList<u8>, VariableList<u16>, VariableList<u16>, VariableList<u16>, VariableList<u16>), DslError>
Compiles a Tree into static index data structures consumed by Index.
store_ids is the ordered list of store identifier strings as defined by the caller.
The index position becomes the store_id (u8) baked into leaf data.
Returns Err(DslError::LimitExceeded) if any compile-time limit is exceeded.
use context_engine::{Tree, dsl::Dsl};
let tree = Tree::Mapping(alloc::vec![
(b"id".to_vec(), Tree::Null),
]);
let (paths, ..) = Dsl::compile(&tree, &[]).unwrap();
assert_eq!(paths.data.len(), 2); // virtual root + idAuto Trait Implementations
impl Freeze for Dsl
impl RefUnwindSafe for Dsl
impl Send for Dsl
impl Sync for Dsl
impl Unpin for Dsl
impl UnsafeUnpin for Dsl
impl UnwindSafe for Dsl